amachine.cli.build_docs API documentation

GitLab Repo

# amachine.cli.build_docs

View Source

    1import subprocess
    2
    3def build_docs():
    4    subprocess.run( ["python", "-m", "pdoc", "-o", "./docs", "--template-directory", "./docs/templates/", "--mermaid", "--docformat", "google", "--math", "--logo", "resources/logo.png", "src/amachine/"] )

def build_docs(): View Source

    4def build_docs():
    5    subprocess.run( ["python", "-m", "pdoc", "-o", "./docs", "--template-directory", "./docs/templates/", "--mermaid", "--docformat", "google", "--math", "--logo", "resources/logo.png", "src/amachine/"] )